@@ -3,113 +3,112 @@
 from typing import Any
 from urllib import parse
 
-_BASE = 'https://smart.vaillant.com/mobile/api/v4'
+_BASE = "https://smart.vaillant.com/mobile/api/v4"
 
-_BASE_AUTHENTICATE = _BASE + '/account/authentication/v1'
-_AUTHENTICATE = _BASE_AUTHENTICATE + '/authenticate'
-_NEW_TOKEN = _BASE_AUTHENTICATE + '/token/new'
-_LOGOUT = _BASE_AUTHENTICATE + '/logout'
+_BASE_AUTHENTICATE = _BASE + "/account/authentication/v1"
+_AUTHENTICATE = _BASE_AUTHENTICATE + "/authenticate"
+_NEW_TOKEN = _BASE_AUTHENTICATE + "/token/new"
+_LOGOUT = _BASE_AUTHENTICATE + "/logout"
 
 """Facility details"""
-_FACILITIES_LIST = _BASE + '/facilities'
-_FACILITIES = _FACILITIES_LIST + '/{serial}'
-_GATEWAY_TYPE = _FACILITIES + '/public/v1/gatewayType'
-_FACILITIES_DETAILS = _FACILITIES + '/system/v1/details'
-_FACILITIES_STATUS = _FACILITIES + '/system/v1/status'
-_FACILITIES_SETTINGS = _FACILITIES + '/storage'
-_FACILITIES_DEFAULT_SETTINGS = _FACILITIES + '/storage/default'
-_FACILITIES_INSTALLER_INFO = _FACILITIES + '/system/v1/installerinfo'
+_FACILITIES_LIST = _BASE + "/facilities"
+_FACILITIES = _FACILITIES_LIST + "/{serial}"
+_GATEWAY_TYPE = _FACILITIES + "/public/v1/gatewayType"
+_FACILITIES_DETAILS = _FACILITIES + "/system/v1/details"
+_FACILITIES_STATUS = _FACILITIES + "/system/v1/status"
+_FACILITIES_SETTINGS = _FACILITIES + "/storage"
+_FACILITIES_DEFAULT_SETTINGS = _FACILITIES + "/storage/default"
+_FACILITIES_INSTALLER_INFO = _FACILITIES + "/system/v1/installerinfo"
 
 """Rbr (Room by room)"""
-_RBR_BASE = _FACILITIES + '/rbr/v1'
-_RBR_INSTALLATION_STATUS = _RBR_BASE + '/installationStatus'
-_RBR_UNDERFLOOR_HEATING_STATUS = _RBR_BASE + '/underfloorHeatingStatus'
+_RBR_BASE = _FACILITIES + "/rbr/v1"
+_RBR_INSTALLATION_STATUS = _RBR_BASE + "/installationStatus"
+_RBR_UNDERFLOOR_HEATING_STATUS = _RBR_BASE + "/underfloorHeatingStatus"
 
 """Rooms"""
-_ROOMS_LIST = _RBR_BASE + '/rooms'
-_ROOM = _ROOMS_LIST + '/{id}'
-_ROOM_CONFIGURATION = _ROOM + '/configuration'
-_ROOM_QUICK_VETO = _ROOM_CONFIGURATION + '/quickVeto'
-_ROOM_TIMEPROGRAM = _ROOM + '/timeprogram'
-_ROOM_OPERATING_MODE = _ROOM_CONFIGURATION + '/operationMode'
-_ROOM_CHILD_LOCK = _ROOM_CONFIGURATION + '/childLock'
-_ROOM_NAME = _ROOM_CONFIGURATION + '/name'
-_ROOM_DEVICE_NAME = _ROOM_CONFIGURATION + '/devices/{sgtin}/name'
-_ROOM_TEMPERATURE_SETPOINT = _ROOM_CONFIGURATION + '/temperatureSetpoint'
+_ROOMS_LIST = _RBR_BASE + "/rooms"
+_ROOM = _ROOMS_LIST + "/{id}"
+_ROOM_CONFIGURATION = _ROOM + "/configuration"
+_ROOM_QUICK_VETO = _ROOM_CONFIGURATION + "/quickVeto"
+_ROOM_TIMEPROGRAM = _ROOM + "/timeprogram"
+_ROOM_OPERATING_MODE = _ROOM_CONFIGURATION + "/operationMode"
+_ROOM_CHILD_LOCK = _ROOM_CONFIGURATION + "/childLock"
+_ROOM_NAME = _ROOM_CONFIGURATION + "/name"
+_ROOM_DEVICE_NAME = _ROOM_CONFIGURATION + "/devices/{sgtin}/name"
+_ROOM_TEMPERATURE_SETPOINT = _ROOM_CONFIGURATION + "/temperatureSetpoint"
 
 """Repeaters"""
-_REPEATERS_LIST = _RBR_BASE + '/repeaters'
-_REPEATER_DELETE = _REPEATERS_LIST + '/{sgtin}'
-_REPEATER_SET_NAME = _REPEATERS_LIST + '/{sgtin}/name'
+_REPEATERS_LIST = _RBR_BASE + "/repeaters"
+_REPEATER_DELETE = _REPEATERS_LIST + "/{sgtin}"
+_REPEATER_SET_NAME = _REPEATERS_LIST + "/{sgtin}/name"
 
 """HVAC (heating, ventilation and Air-conditioning)"""
-_HVAC = _FACILITIES + '/hvacstate/v1/overview'
-_HVAC_REQUEST_UPDATE = _FACILITIES + '/hvacstate/v1/hvacMessages/update'
+_HVAC = _FACILITIES + "/hvacstate/v1/overview"
+_HVAC_REQUEST_UPDATE = _FACILITIES + "/hvacstate/v1/hvacMessages/update"
 
 """EMF (Embedded Metering Function)"""
-_LIVE_REPORT = _FACILITIES + '/livereport/v1'
-_LIVE_REPORT_DEVICE = _LIVE_REPORT + '/devices/{device_id}/reports/{report_id}'
-_PHOTOVOLTAICS_REPORT = _FACILITIES + '/spine/v1/currentPVMeteringInfo'
-_EMF_REPORT = _FACILITIES + '/emf/v1/devices'
-_EMF_REPORT_DEVICE = _EMF_REPORT + '/{device_id}'
+_LIVE_REPORT = _FACILITIES + "/livereport/v1"
+_LIVE_REPORT_DEVICE = _LIVE_REPORT + "/devices/{device_id}/reports/{report_id}"
+_PHOTOVOLTAICS_REPORT = _FACILITIES + "/spine/v1/currentPVMeteringInfo"
+_EMF_REPORT = _FACILITIES + "/emf/v1/devices"
+_EMF_REPORT_DEVICE = _EMF_REPORT + "/{device_id}"
 
 """System control"""
-_SYSTEM = _FACILITIES + '/systemcontrol/v1'
-_SYSTEM_CONFIGURATION = _SYSTEM + '/configuration'
-_SYSTEM_STATUS = _SYSTEM + '/status'
-_SYSTEM_DATETIME = _SYSTEM_STATUS + '/datetime'
-_SYSTEM_PARAMETERS = _SYSTEM + '/parameters'
-_SYSTEM_QUICK_MODE = _SYSTEM_CONFIGURATION + '/quickmode'
-_SYSTEM_HOLIDAY_MODE = _SYSTEM_CONFIGURATION + '/holidaymode'
+_SYSTEM = _FACILITIES + "/systemcontrol/v1"
+_SYSTEM_CONFIGURATION = _SYSTEM + "/configuration"
+_SYSTEM_STATUS = _SYSTEM + "/status"
+_SYSTEM_DATETIME = _SYSTEM_STATUS + "/datetime"
+_SYSTEM_PARAMETERS = _SYSTEM + "/parameters"
+_SYSTEM_QUICK_MODE = _SYSTEM_CONFIGURATION + "/quickmode"
+_SYSTEM_HOLIDAY_MODE = _SYSTEM_CONFIGURATION + "/holidaymode"
 
 """DHW (Domestic Hot Water)"""
-_DHW = _SYSTEM + '/dhw/{id}'
+_DHWS = _SYSTEM + "/dhw"
+_DHW = _DHWS + "/{id}"
 
 """Circulation"""
-_CIRCULATION = _DHW + '/circulation'
-_CIRCULATION_CONFIGURATION = _CIRCULATION + '/configuration'
-_CIRCULATION_TIMEPROGRAM = _CIRCULATION_CONFIGURATION + '/timeprogram'
+_CIRCULATION = _DHW + "/circulation"
+_CIRCULATION_CONFIGURATION = _CIRCULATION + "/configuration"
+_CIRCULATION_TIMEPROGRAM = _CIRCULATION_CONFIGURATION + "/timeprogram"
 
 """Hot water"""
-_HOT_WATER = _DHW + '/hotwater'
-_HOT_WATER_CONFIGURATION = _HOT_WATER + '/configuration'
-_HOT_WATER_TIMEPROGRAM = _HOT_WATER_CONFIGURATION + '/timeprogram'
-_HOT_WATER_OPERATING_MODE = _HOT_WATER_CONFIGURATION + '/operation_mode'
-_HOT_WATER_TEMPERATURE_SETPOINT = _HOT_WATER_CONFIGURATION + \
-                                  '/temperature_setpoint'
+_HOT_WATER = _DHW + "/hotwater"
+_HOT_WATER_CONFIGURATION = _HOT_WATER + "/configuration"
+_HOT_WATER_TIMEPROGRAM = _HOT_WATER_CONFIGURATION + "/timeprogram"
+_HOT_WATER_OPERATING_MODE = _HOT_WATER_CONFIGURATION + "/operation_mode"
+_HOT_WATER_TEMPERATURE_SETPOINT = _HOT_WATER_CONFIGURATION + "/temperature_setpoint"
 
 """Ventilation"""
-_VENTILATION = _SYSTEM + '/ventilation/{id}'
-_VENTILATION_CONFIGURATION = _VENTILATION + '/fan/configuration'
-_VENTILATION_TIMEPROGRAM = _VENTILATION_CONFIGURATION + '/timeprogram'
-_VENTILATION_DAY_LEVEL = _VENTILATION_CONFIGURATION + '/day_level'
-_VENTILATION_NIGHT_LEVEL = _VENTILATION_CONFIGURATION + '/night_level'
-_VENTILATION_OPERATING_MODE = _VENTILATION_CONFIGURATION + '/operation_mode'
+_SYSTEM_VENTILATION = _SYSTEM + "/ventilation"
+_VENTILATION = _SYSTEM + "/ventilation/{id}"
+_VENTILATION_CONFIGURATION = _VENTILATION + "/fan/configuration"
+_VENTILATION_TIMEPROGRAM = _VENTILATION_CONFIGURATION + "/timeprogram"
+_VENTILATION_DAY_LEVEL = _VENTILATION_CONFIGURATION + "/day_level"
+_VENTILATION_NIGHT_LEVEL = _VENTILATION_CONFIGURATION + "/night_level"
+_VENTILATION_OPERATING_MODE = _VENTILATION_CONFIGURATION + "/operation_mode"
 
 """Zones"""
-_ZONES_LIST = _SYSTEM + '/zones'
-_ZONE = _ZONES_LIST + '/{id}'
-_ZONE_CONFIGURATION = _ZONE + '/configuration'
-_ZONE_NAME = _ZONE_CONFIGURATION + '/name'
-_ZONE_QUICK_VETO = _ZONE_CONFIGURATION + '/quick_veto'
+_ZONES_LIST = _SYSTEM + "/zones"
+_ZONE = _ZONES_LIST + "/{id}"
+_ZONE_CONFIGURATION = _ZONE + "/configuration"
+_ZONE_NAME = _ZONE_CONFIGURATION + "/name"
+_ZONE_QUICK_VETO = _ZONE_CONFIGURATION + "/quick_veto"
 
 """Zone heating"""
-_ZONE_HEATING_CONFIGURATION = _ZONE + '/heating/configuration'
-_ZONE_HEATING_TIMEPROGRAM = _ZONE + '/heating/timeprogram'
-_ZONE_HEATING_MODE = _ZONE_HEATING_CONFIGURATION + '/mode'
-_ZONE_HEATING_SETPOINT_TEMPERATURE = _ZONE_HEATING_CONFIGURATION + \
-                                     '/setpoint_temperature'
-_ZONE_HEATING_SETBACK_TEMPERATURE = _ZONE_HEATING_CONFIGURATION + \
-                                    '/setback_temperature'
+_ZONE_HEATING_CONFIGURATION = _ZONE + "/heating/configuration"
+_ZONE_HEATING_TIMEPROGRAM = _ZONE + "/heating/timeprogram"
+_ZONE_HEATING_MODE = _ZONE_HEATING_CONFIGURATION + "/mode"
+_ZONE_HEATING_SETPOINT_TEMPERATURE = _ZONE_HEATING_CONFIGURATION + "/setpoint_temperature"
+_ZONE_HEATING_SETBACK_TEMPERATURE = _ZONE_HEATING_CONFIGURATION + "/setback_temperature"
 
 """Zone cooling"""
-_ZONE_COOLING_CONFIGURATION = _ZONE + '/cooling/configuration'
-_ZONE_COOLING_TIMEPROGRAM = _ZONE + '/cooling/timeprogram'
-_ZONE_COOLING_MODE = _ZONE_COOLING_CONFIGURATION + '/mode'
-_ZONE_COOLING_SETPOINT_TEMPERATURE = _ZONE_COOLING_CONFIGURATION + \
-                                     '/setpoint_temperature'
-_ZONE_COOLING_MANUAL_SETPOINT_TEMPERATURE = \
-    _ZONE_COOLING_CONFIGURATION + '/manual_mode_cooling_temperature_setpoint'
+_ZONE_COOLING_CONFIGURATION = _ZONE + "/cooling/configuration"
+_ZONE_COOLING_TIMEPROGRAM = _ZONE + "/cooling/timeprogram"
+_ZONE_COOLING_MODE = _ZONE_COOLING_CONFIGURATION + "/mode"
+_ZONE_COOLING_SETPOINT_TEMPERATURE = _ZONE_COOLING_CONFIGURATION + "/setpoint_temperature"
+_ZONE_COOLING_MANUAL_SETPOINT_TEMPERATURE = (
+    _ZONE_COOLING_CONFIGURATION + "/manual_mode_cooling_temperature_setpoint"
+)
 
 
 def base(**kwargs: Any) -> str:
@@ -185,8 +184,7 @@ def room_quick_veto(**kwargs: Any) -> str:
 
 
 def room_operating_mode(**kwargs: Any) -> str:
-    """Url to set operating for a :class:`~pymultimatic.model.component.Room`.
-    """
+    """Url to set operating for a :class:`~pymultimatic.model.component.Room`."""
     return _ROOM_OPERATING_MODE.format(**kwargs)
 
 
@@ -271,22 +269,22 @@ def emf_report(**kwargs: Any) -> str:
     return _EMF_REPORT.format(**kwargs)
 
 
-# pylint: disable=too-many-arguments
-def emf_report_device(energy_type: str, function: str, time_range: str,
-                      start: str, offset: str, **kwargs: Any) -> str:
+def emf_report_device(
+    energy_type: str, function: str, time_range: str, start: str, offset: str, **kwargs: Any
+) -> str:
     """Url to get emf (Embedded Metering Function) report for a specific
     device."""
     url = _EMF_REPORT_DEVICE.format(**kwargs)
 
     query_params = {
-        'energyType': energy_type,
-        'function': function,
-        'timeRange': time_range,
-        'start': start,
-        'offset': offset,
+        "energyType": energy_type,
+        "function": function,
+        "timeRange": time_range,
+        "start": start,
+        "offset": offset,
     }
 
-    return '{}?{}'.format(url, parse.urlencode(query_params))
+    return "{}?{}".format(url, parse.urlencode(query_params))
 
 
 def facilities_details(**kwargs: Any) -> str:
@@ -362,9 +360,16 @@ def dhw(**kwargs: Any) -> str:
     return _DHW.format(**kwargs)
 
 
-def circulation(**kwargs: Any) -> str:
-    """Url to get :class:`~pymultimatic.model.component.Circulation` details.
+def dhws(**kwargs: Any) -> str:
+    """Url to get all domestic hot water
+    (:class:`~pymultimatic.model.component.HotWater` and
+    :class:`~pymultimatic.model.component.Circulation`).
     """
+    return _DHWS.format(**kwargs)
+
+
+def circulation(**kwargs: Any) -> str:
+    """Url to get :class:`~pymultimatic.model.component.Circulation` details."""
     return _CIRCULATION.format(**kwargs)
 
 
@@ -420,6 +425,11 @@ def ventilation(**kwargs: Any) -> str:
     return _VENTILATION.format(**kwargs)
 
 
+def system_ventilation(**kwargs: Any) -> str:
+    """Url to get ventilation details."""
+    return _SYSTEM_VENTILATION.format(**kwargs)
+
+
 def ventilation_configuration(**kwargs: Any) -> str:
     """Url to get ventilation configuration."""
     return _VENTILATION_CONFIGURATION.format(**kwargs)
@@ -491,8 +501,7 @@ def zone_heating_timeprogram(**kwargs: Any) -> str:
 
 
 def zone_heating_mode(**kwargs: Any) -> str:
-    """Url to get a :class:`~pymultimatic.model.component.Zone` heating mode.
-    """
+    """Url to get a :class:`~pymultimatic.model.component.Zone` heating mode."""
     return _ZONE_HEATING_MODE.format(**kwargs)
 
 
@@ -525,8 +534,7 @@ def zone_cooling_timeprogram(**kwargs: Any) -> str:
 
 
 def zone_cooling_mode(**kwargs: Any) -> str:
-    """Url to set a :class:`~pymultimatic.model.component.Zone` cooling mode.
-    """
+    """Url to set a :class:`~pymultimatic.model.component.Zone` cooling mode."""
     return _ZONE_COOLING_MODE.format(**kwargs)
 
 
